@@ -11,8 +11,12 @@
 }
 
 .onAttach <- function(libname, pkgname){
-  if (grepl("mingw", R.Version()$platform) && !file.exists(get_bundle()))
-    warning("No CA bundle found. SSL validation disabled.", call. = FALSE)
+  if (grepl("mingw", R.Version()$platform) && !file.exists(get_bundle())){
+    packageStartupMessage("No CA bundle found. SSL validation disabled.")
+
+    # CRAN does not like warnings for r-oldrel. Fix once R 3.3 is out:
+    #warning("No CA bundle found. SSL validation disabled.", call. = FALSE)
+  }
 }
 
 #' @useDynLib curl R_set_bundle
